﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using WpfApplication1.Model;

namespace WpfApplication1.ViewModel
{
  public class MainViewModel : INotifyPropertyChanged
  {
    private readonly ObservableCollection<Person> _persons = new ObservableCollection<Person>();
    
    public ObservableCollection<Person> Persons
    {
      get { return _persons; }
    }

    private Person _selectedPerson;
    private readonly DelegateCommand _command;

    private void ShowDetail(object obj)
    {
      OnPropertyChanged("Name");
    }

    public Person SelectedPerson
    {
      get { return _selectedPerson; }
      set
      {
        if (!Equals(value, _selectedPerson))
        {
          _selectedPerson = value;

          if (Command != null)
          {
            Command.RaiseCanExecuteChanged();
          }
        }
      }
    }

    public DelegateCommand Command
    {
      get { return _command; }
    }

    public string Name
    {
      get
      {
        if (SelectedPerson == null)
        {
          return null;
        }
        return SelectedPerson.Name;
      }
    }

    public MainViewModel()
    {
      _command = new DelegateCommand(ShowDetail, CanShowDetail);

      _persons.Add(new Person()
      {
        Name = "Jaroslav Nečas"
      });

      _persons.Add(new Person()
      {
        Name = "Batman"
      });

      _persons.Add(new Person()
      {
        Name = "Spiderman"
      });
    }

    private bool CanShowDetail(object obj)
    {
      return SelectedPerson != null;
    }

    public event PropertyChangedEventHandler PropertyChanged;

    protected void OnPropertyChanged( string propertyName = null)
    {
      var handler = PropertyChanged;
      if (handler != null)
      {
        handler(this, new PropertyChangedEventArgs(propertyName));
      }
    }
  }
}
